==> haskell-hls-eval-plugin-2.0.0.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-eval-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-eval-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-eval-plugin-2.0.0.0-5S9Q5Jf1sTn3SMTheGTECb
key:                  hls-eval-plugin-2.0.0.0-5S9Q5Jf1sTn3SMTheGTECb
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8afb9a2d52a6b79a2c4f70656ca4d4af
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-eval-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-eval-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.0.0.0-5S9Q5Jf1sTn3SMTheGTECb
depends:
    Diff-0.4.1-FQGoMszL7yvHgYjHqpLdBw
    QuickCheck-2.14.3-GYIzHRC98oX2ojVETG14rD
    aeson-2.1.2.1-EcnOkqJy6qkFyx4PSoTHhT base-4.16.4.0
    containers-0.6.5.1 data-default-0.7.1.1-4Q2QEONQl2rBpJbSE6OFE3
    deepseq-1.4.6.1 directory-1.3.6.2 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    extra-1.7.16-EWGdPHvQLeb5EiMAbHqdrp filepath-1.4.2.2 ghc-9.2.8
    ghc-boot-th-9.2.8 ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp
    ghcide-2.0.0.0-3VpLNJ1hOcd6vhojPJ3y0z
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    hls-graph-2.0.0.0-L27kkyboPrE6IM0C2grSIK
    hls-plugin-api-2.0.0.0-8gJDyqB5fRDBrSpxKPB9t3
    lens-5.2.3-I3ec5MPKyg91QrvRMYPpyk
    lsp-1.6.0.0-6L8sJShQLXFEvvyFemQeyc
    lsp-types-1.6.0.1-CcisWdy83bs2cRfS460TzT
    megaparsec-9.6.1-1rJqRfK4Cgi6LJwevmLrVi mtl-2.2.2
    parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5
    pretty-simple-4.1.2.0-622oUKBgrcr8IlEzHn7AMF
    safe-exceptions-0.1.7.4-GPoXaqbHmse2qLBXsbf3lC text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-0.2.25.1-8L6BiCnh80y1RfJtEqTngb
    unordered-containers-0.2.20-DtI6Ump4gwL4XOoZ2vYwmp

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-eval-plugin-2.0.0.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-eval-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-eval-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-eval-plugin-2.0.0.0-DKXgOc3qc6T3dxREdIvVfn
key:                  hls-eval-plugin-2.0.0.0-DKXgOc3qc6T3dxREdIvVfn
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  b0bc790229c3e398b3852ae5a03dd40d
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-eval-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-eval-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.0.0.0-DKXgOc3qc6T3dxREdIvVfn
depends:
    Diff-0.4.1-FQGoMszL7yvHgYjHqpLdBw
    QuickCheck-2.14.3-GYIzHRC98oX2ojVETG14rD
    aeson-2.1.2.1-LOsc8VZqmR4FTSS4ItJTX9 base-4.16.4.0
    containers-0.6.5.1 data-default-0.7.1.1-4Q2QEONQl2rBpJbSE6OFE3
    deepseq-1.4.6.1 directory-1.3.6.2 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    extra-1.7.16-9QXTGuykCno1FsMdBZzFkU filepath-1.4.2.2 ghc-9.2.8
    ghc-boot-th-9.2.8 ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp
    ghcide-2.0.0.0-I3J9NvI9d01ALoTKFbdwiW
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    hls-graph-2.0.0.0-7vHjdFidOuaWJTdbePsOx
    hls-plugin-api-2.0.0.0-4DvTbxgjpIK6D8yMZ4340P
    lens-5.2.3-Ay8F9EUtjnE9PU0we5yejR
    lsp-1.6.0.0-BDoA34rM2HDFusakTyA3Cp
    lsp-types-1.6.0.1-6MFESEXO2KgKndN8rLema4
    megaparsec-9.6.1-1rJqRfK4Cgi6LJwevmLrVi mtl-2.2.2
    parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5
    pretty-simple-4.1.2.0-F4UGQqa3lcyCmtSAGYx2cx
    safe-exceptions-0.1.7.4-GPoXaqbHmse2qLBXsbf3lC text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-0.2.25.1-8L6BiCnh80y1RfJtEqTngb
    unordered-containers-0.2.20-DtI6Ump4gwL4XOoZ2vYwmp

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
